@@ -4,8 +4,10 @@
 #include "defines.h"
 #include "frend.h"
 #include "misc.h"
+#include "skins.h"
 
-class s9x_CPU :		public s9x_Notepage {
+class s9x_CPU :		public s9x_Notepage
+{
  private:
    fr_Checkbox		HDMA;
    fr_Checkbox		SpeedHacks;
@@ -14,11 +16,8 @@ class s9x_CPU :		public s9x_Notepage {
    fr_Slider		Cycles;
    void			EventOccurred(fr_Event*e);
  public:
- 			s9x_CPU(fr_Element*parent);
-   void			SetToDefaults();
-   void			Set9xVersion(float version);
-   void			SiftArgs(fr_ArgList& L);
-   void			CompileArgs(fr_ArgList& L);
+ 			s9x_CPU(fr_Notebook*parent);
+  void			Set9xVersion(float version);
 };                                                                          
 
 #endif
