@@ -1,31 +1,32 @@
+#include <string>
 #include "defines.h"
 #include "frend.h"
 #include "misc.h"
+#include "skins.h"
 
 #ifndef S9X_EXTRA_H
 #define S9X_EXTRA_H
 
-class s9x_Snapshot :    public s9x_Notepage {
+class s9x_Snapshot :    public s9x_Notepage
+{
  private:
    fr_Label		Desc;
    fr_File		File;
    void			EventOccurred(fr_Event*e);
  public:
-	                s9x_Snapshot(fr_Element*parent);
-   void            	SetToDefaults();
+	                s9x_Snapshot(fr_Notebook*parent);
    void			FilePopup();
-   void            	SiftArgs(fr_ArgList& L);
-   void            	CompileArgs(fr_ArgList& L);
 };
 
-class s9x_Extra :       public s9x_Notepage {
+class s9x_Extra :       public s9x_Notepage
+{
  protected:
-   char			ArgStr[256];
+   std::string		ArgStr;
    fr_Label		Desc;
    fr_Text         	Options;
    void			EventOccurred(fr_Event*e);
  public:
-	                s9x_Extra(fr_Element*parent);
+	                s9x_Extra(fr_Notebook*parent);
    void            	SetToDefaults();
    void            	SiftArgs(fr_ArgList& L);
    void			CompileArgs(fr_ArgList& L);
